#
# spec file for package plowshare
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           plowshare
Version:        2.1.7
Release:        bp153.2.1
Summary:        Download and upload files from file-sharing websites
License:        GPL-3.0+
Group:          Productivity/Networking/Web/Utilities
Url:            https://github.com/mcrapet/plowshare
Source0:        https://github.com/mcrapet/plowshare/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM
Patch0:         reproducible.patch
BuildRequires:  bash >= 4.1
BuildRequires:  curl >= 7.24
Requires:       bash >= 4.1
Requires:       curl >= 7.24
Requires:       perl
Requires:       perl(HTML::Entities)
Recommends:     bash-completion
Provides:       %{name}-bash-completion = %{version}
Obsoletes:      %{name}-bash-completion < %{version}
BuildArch:      noarch

%description
plowshare is a command-line (CLI) download/upload tool for popular file
sharing websites (aka file hosting provider or One-Click hoster). With
plowshare, you will be able to download or upload files and manage remote
folders and link deletion. It runs on Linux/BSD/Unix operating system. The
basic concept is that files can be downloaded and uploaded though command
line as easily as wget (or curl).

%prep
%setup -q
%patch0 -p1

%build

%install
%make_install
install -D -p -m 0644  scripts/%{name}.completion  %{buildroot}%{_datadir}/bash-completion/completions/%{name}
sed -i 's|/local||g' %{buildroot}%{_datadir}/bash-completion/completions/%{name}
rm -rf  %{buildroot}%{_datadir}/doc/%{name}

%files
%doc COPYING CHANGELOG README.md docs/plowshare.conf.sample
%{_bindir}/plowdel
%{_bindir}/plowdown
%{_bindir}/plowlist
%{_bindir}/plowmod
%{_bindir}/plowprobe
%{_bindir}/plowup
%{_datadir}/plowshare
%{_datadir}/bash-completion
%{_mandir}/man1/plowdel.1%{ext_man}
%{_mandir}/man1/plowdown.1%{ext_man}
%{_mandir}/man1/plowlist.1%{ext_man}
%{_mandir}/man1/plowmod.1%{ext_man}
%{_mandir}/man1/plowprobe.1%{ext_man}
%{_mandir}/man1/plowup.1%{ext_man}
%{_mandir}/man5/%{name}.conf.5%{ext_man}
%ghost %config(noreplace) %{_sysconfdir}/plowshare.conf

%changelog
* Tue Jun 11 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to override build date (boo#1047218)
* Mon Aug 28 2017 mpluskal@suse.com
- Update to version 2.1.7:
  * [plowdown] support --run-before/--run-after with spaces (#74)
  * [plowdown] add --min-rate switch (#91)
  * [core] user plowshare.conf can be a symbolic link (#95)
* Mon Jul 24 2017 tchvatal@suse.com
- Switch to perl from recode for conversions wrt fate#323644
* Thu Nov 24 2016 mpluskal@suse.com
- Update to version 2.1.6:
  * API function delete_filter_line: eat lines until regexp is met.
    Bump PLOWSHARE_API_VERSION to 6.
  * [core] Handle CONT signal (wait time will be updated on ^Z)
  * [core] Introduce PLOWSHARE_CURL and PLOWSHARE_JS environment
    variables to override default curl and js commands.
* Thu Aug 18 2016 mpluskal@suse.com
- Update to version 2.1.5:
  * Various documentation and help improvements
  * [plowlist] Add -t/--timeout command-line switch (useful for
  * mirroring/multiupload hosters)
  * API function delete_last_line: add second optional argument
    (number of lines).
  * Bump PLOWSHARE_API_VERSION to 5.
  * [core] Consider $XDG_CONFIG_HOME (default is ~/.config)
- Changes for version 2.1.4:
  * [plowup] allow local/remote filename having , or ; characters.
    This is a workaround to curl limitation. (#37)
  * New API for modules: sha1_file(). Bump PLOWSHARE_API_VERSION
    to 4.
  * [plowup] Add %%T --printf token to get (current) time (#45)
  * [core] update imgur API to 3 (#42)
* Thu Mar 31 2016 mpluskal@suse.com
- Update to 2.1.3
  * [core] update reCAPTCHA behavior (PR #36)
  * [plowup] Add --run-before switch
  * New internal error code (for modules): $ERR_EXPIRED_SESSION.
    Bump PLOWSHARE_API_VERSION to 3.
- Spec file cleanups
* Tue Sep  1 2015 mpluskal@suse.com
- Update to 2.1.2
  * [core] Minor fixes. More cygwin/bsd friendly.
- Merge bash completion to main package
* Thu May  7 2015 mpluskal@suse.com
- Update to 2.1.1
  * [plowmod] Fixes with git (requires git v1.8.5+)
  * [plowmod] Add --status command-line switch
- Changes for 2.1.0)
  * Documentation refactor. Add plowshare.conf.sample file.
  * Support user modules ~/.config/plowshare/modules.d/* scheme
  * [plowmod] Add tool to ease modules repositories management
- Changes for 2.0.1
  * bash completion (plowdown, plowup): add missing --cache support
  * Enhance documentation concerning split of modules and core
- Changes for 2.0.0
  * First version shipped without any module. Only core here.
    Module sources have been committed in a new GIT repository.
* Sun Nov  9 2014 mpluskal@suse.com
-  Switch to github source due to unreliability of downloads from google (sr#260344)
* Sat Nov  8 2014 mpluskal@suse.com
- Reapackaged home:Warhammer40k:stuff
